@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2021 Elyra Authors
+ * Copyright 2018-2022 Elyra Authors
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -53,7 +53,7 @@ import React from 'react';
 
 import {
   CodeSnippetService,
-  CODE_SNIPPET_NAMESPACE,
+  CODE_SNIPPET_SCHEMASPACE,
   CODE_SNIPPET_SCHEMA
 } from './CodeSnippetService';
 
@@ -78,7 +78,7 @@ interface ICodeSnippetDisplayProps extends IMetadataDisplayProps {
   metadata: IMetadata[];
   openMetadataEditor: (args: any) => void;
   updateMetadata: () => void;
-  namespace: string;
+  schemaspace: string;
   schema: string;
   sortMetadata: boolean;
   className: string;
@@ -107,7 +107,8 @@ class CodeSnippetDisplay extends MetadataDisplay<
   // Handle code snippet insertion into an editor
   private insertCodeSnippet = async (snippet: IMetadata): Promise<void> => {
     const widget = this.props.getCurrentWidget();
-    const snippetStr = snippet.metadata.code.join('\n');
+    const codeSnippet = snippet.metadata.code.join('\n');
+    const snippetLanguage = snippet.metadata.language;
 
     if (widget === null) {
       return;
@@ -116,19 +117,19 @@ class CodeSnippetDisplay extends MetadataDisplay<
     if (this.isFileEditor(widget)) {
       const fileEditor = widget.content.editor;
       const markdownRegex = /^\.(md|mkdn?|mdown|markdown)$/;
+      const editorLanguage = this.getEditorLanguage(widget);
+
       if (
         PathExt.extname(widget.context.path).match(markdownRegex) !== null &&
-        snippet.metadata.language.toLowerCase() !== 'markdown'
+        snippetLanguage.toLowerCase() !== 'markdown'
       ) {
         fileEditor.replaceSelection?.(
-          this.addMarkdownCodeBlock(snippet.metadata.language, snippetStr)
+          this.addMarkdownCodeBlock(snippetLanguage, codeSnippet)
         );
-      } else if (widget.constructor.name === 'ScriptEditor') {
-        const editorLanguage =
-          widget.context.sessionContext.kernelPreference.language;
-        this.verifyLanguageAndInsert(snippet, editorLanguage ?? '', fileEditor);
+      } else if (editorLanguage) {
+        this.verifyLanguageAndInsert(snippet, editorLanguage, fileEditor);
       } else {
-        fileEditor.replaceSelection?.(snippetStr);
+        fileEditor.replaceSelection?.(codeSnippet);
       }
     } else if (widget instanceof NotebookPanel) {
       const notebookWidget = widget as NotebookPanel;
@@ -153,13 +154,13 @@ class CodeSnippetDisplay extends MetadataDisplay<
         );
       } else if (
         notebookCell instanceof MarkdownCell &&
-        snippet.metadata.language.toLowerCase() !== 'markdown'
+        snippetLanguage.toLowerCase() !== 'markdown'
       ) {
         notebookCellEditor.replaceSelection?.(
-          this.addMarkdownCodeBlock(snippet.metadata.language, snippetStr)
+          this.addMarkdownCodeBlock(snippetLanguage, codeSnippet)
         );
       } else {
-        notebookCellEditor.replaceSelection?.(snippetStr);
+        notebookCellEditor.replaceSelection?.(codeSnippet);
       }
       const cell = notebookWidget.model?.contentFactory.createCodeCell({});
       if (cell === undefined) {
@@ -178,6 +179,15 @@ class CodeSnippetDisplay extends MetadataDisplay<
     return (widget as DocumentWidget).content instanceof FileEditor;
   };
 
+  // Return the language of the editor or empty string
+  private getEditorLanguage = (
+    widget: DocumentWidget<FileEditor>
+  ): string | undefined => {
+    const editorLanguage =
+      widget.context.sessionContext.kernelPreference.language;
+    return editorLanguage === 'null' ? '' : editorLanguage;
+  };
+
   // Return the given code wrapped in a markdown code block
   private addMarkdownCodeBlock = (language: string, code: string): string => {
     return '```' + language + '\n' + code + '\n```';
@@ -189,21 +199,22 @@ class CodeSnippetDisplay extends MetadataDisplay<
     editorLanguage: string,
     editor: CodeEditor.IEditor
   ): Promise<void> => {
-    const snippetStr: string = snippet.metadata.code.join('\n');
+    const codeSnippet: string = snippet.metadata.code.join('\n');
+    const snippetLanguage = snippet.metadata.language;
     if (
       editorLanguage &&
-      snippet.metadata.language.toLowerCase() !== editorLanguage.toLowerCase()
+      snippetLanguage.toLowerCase() !== editorLanguage.toLowerCase()
     ) {
       const result = await this.showWarnDialog(
         editorLanguage,
         snippet.display_name
       );
       if (result.button.accept) {
-        editor.replaceSelection?.(snippetStr);
+        editor.replaceSelection?.(codeSnippet);
       }
     } else {
       // Language match or editorLanguage is unavailable
-      editor.replaceSelection?.(snippetStr);
+      editor.replaceSelection?.(codeSnippet);
     }
   };
 
@@ -392,7 +403,7 @@ class CodeSnippetDisplay extends MetadataDisplay<
         onClick: (): void => {
           this.props.openMetadataEditor({
             onSave: this.props.updateMetadata,
-            namespace: CODE_SNIPPET_NAMESPACE,
+            schemaspace: CODE_SNIPPET_SCHEMASPACE,
             schema: CODE_SNIPPET_SCHEMA,
             name: metadata.name
           });
@@ -412,7 +423,7 @@ class CodeSnippetDisplay extends MetadataDisplay<
                   (value: Widget, index: number) => {
                     return (
                       value.id ==
-                      `${METADATA_EDITOR_ID}:${CODE_SNIPPET_NAMESPACE}:${CODE_SNIPPET_SCHEMA}:${metadata.name}`
+                      `${METADATA_EDITOR_ID}:${CODE_SNIPPET_SCHEMASPACE}:${CODE_SNIPPET_SCHEMA}:${metadata.name}`
                     );
                   }
                 );
@@ -530,7 +541,7 @@ class CodeSnippetDisplay extends MetadataDisplay<
 export interface ICodeSnippetWidgetProps extends IMetadataWidgetProps {
   app: JupyterFrontEnd;
   display_name: string;
-  namespace: string;
+  schemaspace: string;
   schema: string;
   icon: LabIcon;
   getCurrentWidget: () => Widget | null;
@@ -570,7 +581,7 @@ export class CodeSnippetWidget extends MetadataWidget {
         metadata={metadata}
         openMetadataEditor={this.openMetadataEditor}
         updateMetadata={this.updateMetadata}
-        namespace={CODE_SNIPPET_NAMESPACE}
+        schemaspace={CODE_SNIPPET_SCHEMASPACE}
         schema={CODE_SNIPPET_SCHEMA}
         getCurrentWidget={this.props.getCurrentWidget}
         className={CODE_SNIPPETS_METADATA_CLASS}
